@@ -2,7 +2,6 @@
 #define __CACHEDATABASE_H__
 
 #include "global.h"
-#include <QtSql>
 
 class ContactsModel;
 class InboxModel;
@@ -15,6 +14,8 @@ private:
     CacheDatabase(const QSqlDatabase &other, QObject *parent = 0);
     ~CacheDatabase(void);
 
+    QString get_db_name ();
+
 public:
     void init ();
     void deinit ();
